pub enum IoMode {
UringDirect,
Uring,
UringMultiAsync,
UringShared,
UringBlocking,
StdBlocking,
TokioIO,
StdSpawnBlocking,
}Expand description
Mode in which Disk IO is done (direct IO or page cache)
Variants
UringDirect
Uses io_uring and bypass the page cache (uses direct IO), only available on Linux
Uring
Uses io_uring and uses OS’s page cache, only available on Linux
UringMultiAsync
Uses multiple async io_uring instances leased per future, only available on Linux
Uses io_uring with a single shared ring on the runtime thread, only available on Linux
UringBlocking
Uses io_uring on the calling thread and blocks until completion.
StdBlocking
Uses rust’s std::fs::File, this is blocking IO.
On Linux, this is essentially pread/pwrite
This is the default on non-Linux platforms.
TokioIO
Uses tokio’s async IO, this is non-blocking IO, but quite slow: https://github.com/tokio-rs/tokio/issues/3664
StdSpawnBlocking
Use rust’s std::fs::File, but will try to spawn_blocking, just like object_store does:
https://github.com/apache/arrow-rs-object-store/blob/28b2fc563feb44bb3d15718cf58036772334a704/src/datafusion-local.rs#L440-L448